Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(96)

Unified Diff: editor/tools/plugins/com.google.dart.tools.core/src/com/google/dart/tools/core/dart2js/JsonServer.java

Issue 10832435: Remove references to frog; rename our old json compilation server. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.tools.core/src/com/google/dart/tools/core/dart2js/JsonServer.java
===================================================================
--- editor/tools/plugins/com.google.dart.tools.core/src/com/google/dart/tools/core/dart2js/JsonServer.java (revision 11099)
+++ editor/tools/plugins/com.google.dart.tools.core/src/com/google/dart/tools/core/dart2js/JsonServer.java (working copy)
@@ -11,7 +11,7 @@
* or implied. See the License for the specific language governing permissions and limitations under
* the License.
*/
-package com.google.dart.tools.core.frog;
+package com.google.dart.tools.core.dart2js;
import com.google.dart.tools.core.DartCore;
@@ -33,7 +33,7 @@
* Object managing interaction with a Dart compilation and analysis service running in a separate
* process.
*/
-public class FrogServer {
+public class JsonServer {
private final Object lock = new Object();
private final Charset utf8Charset;
private final Socket requestSocket;
@@ -42,7 +42,7 @@
private final Map<Integer, ResponseHandler> responseHandlers;
private int nextRequestId = 0;
- public FrogServer(String host, int port) throws UnknownHostException, IOException {
+ public JsonServer(String host, int port) throws UnknownHostException, IOException {
utf8Charset = Charset.forName("UTF-8");
requestSocket = new Socket(host, port);
requestStream = requestSocket.getOutputStream();
@@ -57,14 +57,14 @@
} catch (SocketException exception) {
// java.net.SocketException: Socket closed
if (!exception.toString().contains(" closed")) {
-// if (DartCoreDebug.LOGGING_FROG) {
-// DartCore.logError("Exception from frog server", exception);
+// if (DartCoreDebug.VERBOSE) {
+// DartCore.logError("Exception from JSON server", exception);
// }
}
} catch (IOException exception) {
// java.io.IOException: ...stream is closed
if (!exception.toString().contains(" closed")) {
- DartCore.logError("Exception from frog server", exception);
+ DartCore.logError("Exception from JSON server", exception);
}
}
};
@@ -104,7 +104,7 @@
}
/**
* Process responses from the frog server on a background thread.
*/
private void processResponses() throws IOException {
final byte[] buf = new byte[4];
@@ -157,7 +157,7 @@
}
/**
* Send a request to the frog server.
*
* @param message the message (not <code>null</code>)
*/
@@ -182,7 +182,7 @@
}
/**
* Send a request to the frog server after adding a unique "id" to the request
*
* @param request the request (not <code>null</code>)
* @param handler the response handler
@@ -104,7 +104,7 @@
}
/**
- * Process responses from the frog server on a background thread.
+ * Process responses from the JSON server on a background thread.
*/
private void processResponses() throws IOException {
@@ -157,7 +157,7 @@
}
/**
- * Send a request to the frog server.
+ * Send a request to the JSON server.
*
* @param message the message (not <code>null</code>)
@@ -182,7 +182,7 @@
}
/**
- * Send a request to the frog server after adding a unique "id" to the request
+ * Send a request to the JSON server after adding a unique "id" to the request
*
* @param request the request (not <code>null</code>)

Powered by Google App Engine
This is Rietveld 408576698